<template>
  <div class="app-container">
    <div style="display: flex;justify-content: space-between">
      <el-form :inline="true" style="display: flex;align-items: center;flex-wrap: wrap;" >
        <el-form-item>
          <el-button
              type="primary"
              plain
              icon="Plus"
              @click="openDialog('add',{})"
          >新增</el-button>
        </el-form-item>
        <el-form-item label="用户名：" >
          <el-input v-model="data.queryParams.username" placeholder="请输入用户名"></el-input>
        </el-form-item>
<!--        <el-form-item label="用户类型：" >-->
<!--          <el-select v-model="data.queryParams.userType" placeholder="请选择" clearable>-->
<!--            <el-option-->
<!--                v-for="item in data.userTypeList"-->
<!--                :key="item.id"-->
<!--                :label="item.name"-->
<!--                :value="item.id">-->
<!--            </el-option>-->
<!--          </el-select>-->
<!--        </el-form-item>-->
        <el-form-item v-if="isAdmin" label="企业：" >
          <el-select v-model="data.queryParams.companyId" placeholder="请选择" clearable>
            <el-option
                v-for="item in companyList"
                :key="item.id"
                :label="item.name"
                :value="item.id">
            </el-option>
          </el-select>
        </el-form-item>
<!--        <el-form-item label="用户名：" >-->
<!--          <el-input v-model="data.queryParams.username" placeholder="请输入用户名"></el-input>-->
<!--        </el-form-item>-->
<!--        <el-form-item label="用户类型：" >-->
<!--          <el-select v-model="data.queryParams.userType" placeholder="请选择" clearable>-->
<!--            <el-option-->
<!--                v-for="item in data.userTypeList"-->
<!--                :key="item.id"-->
<!--                :label="item.name"-->
<!--                :value="item.id">-->
<!--            </el-option>-->
<!--          </el-select>-->
<!--        </el-form-item>-->
        <el-form-item >
          <el-button type="primary" @click="getList">查询</el-button>
          <el-button type="primary" plain @click="reset" style="margin-right: 12px">重置</el-button>
          <vue3-json-excel
              :json-data="expertData"
              :fields="fields"
              name="用户花名册.xls"
          >
            <el-button type="primary">导出</el-button>
          </vue3-json-excel>
        </el-form-item>
      </el-form>
    </div>
    <!-- 表格数据 -->
    <el-table v-loading="loading" :data="dataList" :border="true">
      <el-table-column label="序号" type="index" align="center" width="80" />
      <el-table-column label="用户名" prop="username" align="center"  />
      <el-table-column label="姓名" prop="name" align="center"  />
      <el-table-column label="身份证号" prop="idCard" align="center" />
      <el-table-column label="入职时间" prop="entryTime" align="center"/>
      <el-table-column label="部门" prop="deptName" align="center"/>
      <el-table-column label="职务" prop="duty" align="center"/>
      <el-table-column label="联系方式" prop="phone" align="center"/>
      <el-table-column label="专业" prop="post" align="center"/>
      <el-table-column label="用户类型" prop="userTypeName" align="center"/>
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width" >
        <template #default="scope">
          <el-button link type="primary" @click="openDialog('view',scope.row)">查看</el-button>
          <el-button link type="primary" @click="openDialog('edit',scope.row)">编辑</el-button>
          <el-button link type="danger" @click="handleDelete(scope.row)">删除</el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination
        v-show="total > 0"
        :total="total"
        v-model:page="queryParams.pageNum"
        v-model:limit="queryParams.pageSize"
        @pagination="getList"
    />

    <user-dialog ref="dialogRef" @getList=getList></user-dialog>
  </div>
</template>

<script setup>
import {getCurrentInstance, onMounted, onUnmounted, reactive, ref, toRefs} from "vue";
import {ElMessage, ElMessageBox} from "element-plus";
import {delCompany, getCompany} from "@/api/onlineEducation/company";
import userDialog from './components/staffDialog.vue'
import {delUser, getUser} from "@/api/onlineEducation/user";
import Cookies from "js-cookie";
import useUserStore from "@/store/modules/user";
const userStore = useUserStore()

const { proxy } = getCurrentInstance();
const loading = ref(false);
const dialogRef = ref();
const data = reactive({
  queryParams: {
    pageNum: 1,
    pageSize: 10,
    username: '',
    userType: null,
    companyId: null
  },
  total: 0,
  dataList: [],
  isAdmin: false,
  companyList: [],
  expertData: [],
  userTypeList: [
    {
      id: 0,
      name: '管理员'
    },
    {
      id: 1,
      name: '企业级'
    },
    {
      id: 2,
      name: '部门级'
    },
    {
      id: 3,
      name: '车间（岗位）级别'
    },
    {
      id: 4,
      name: '其他'
    },
  ]

});

const { queryParams, total, dataList,isAdmin,companyList,expertData } = toRefs(data);
const userInfo = ref()
const fields = ref({
  '序号':'index',
  '姓名':'username',
  '身份证号':'idCard',
  '入职时间':'entryTime',
  '部门':'deptName',
  '职务':'duty',
  '联系方式':'phone',
  '专业':'post',
  '用户类型':'userTypeName'
});
onMounted(async ()=>{
  userInfo.value = JSON.parse(Cookies.get('userInfo'))
  if(userStore.roles.includes('admin')){
    data.isAdmin = true
    await getCompanyList()
  }else{
    data.isAdmin = false
    data.queryParams.companyId = userStore.companyId
  }
  await getList()
})

onUnmounted(()=>{

})

const getList = async () => {
  loading.value = true
  const res = await getUser(data.queryParams)
  if(res.code == 200){
    data.dataList = res.data.list.map(item => {
      return {
        ...item,
        userTypeName: item.userType === 0 ? '管理员' : item.userType === 1 ? '企业级' : item.userType === 2 ? '部门级' : item.userType === 3 ? '车间级' :'其他',
        entryTime: item.entryTime?.substring(0, 10)
      }
    })
    data.total = res.data.total
  }else{
    ElMessage.warning(res.message)
  }
  loading.value = false
  await getAllList()
}

const getCompanyList = async ()=>{
  const queryParams = {
    pageNum: 1,
    pageSize: 999
  }
  const res = await getCompany(queryParams)
  if (res.code == 200) {
    data.companyList = res.data.list?res.data.list:[]
    // data.queryParams.companyId = data.companyList[0].id
  } else {
    ElMessage.warning(res.message)
  }
}

const getAllList = async () => {
  const res = await getUser({
    pageNum: 1,
    pageSize: 999,
    username: '',
    userType: null,
    companyId: null
  })
  if(res.code == 200){
    data.expertData = res.data.list.map((item,index) => {
      return {
        ...item,
        index: index + 1,
        userTypeName: item.userType === 0 ? '管理员' : item.userType === 1 ? '企业级' : item.userType === 2 ? '部门级' : item.userType === 3 ? '车间级' :'其他',
        entryTime: item.entryTime?.substring(0, 10)
      }
    })
  }else{
    ElMessage.warning(res.message)
  }
}

const openDialog = (type, value) => {
  if(userInfo.value.userType === 3){
    ElMessage.warning('车间级用户不能新增')
    return;
  }
  dialogRef.value.openDialog(type, value, data.queryParams.companyId);
}

/** 重置新增的表单以及其他数据  */
const reset = async()=> {
  data.queryParams = {
    pageNum: 1,
    pageSize: 10,
    username: '',
    userType: null,
    companyId: null
  }
  await getCompanyList()
  await getList()
}
const handleDelete = (val) => {
  ElMessageBox.confirm(
      '确定删除此条数据？',
      '提示',
      {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning',
      })
      .then( async() => {
        const res = await delUser(val.id)
        if(res.code == 200){
          ElMessage.success('数据删除成功')
          await getList()
        }else{
          ElMessage.warning(res.message)
        }
      })
}

</script>
